@@ -5,6 +5,9 @@ pub mod one_to_set;
 pub mod set_to_one;
 pub mod set_to_set;
 
+#[cfg(test)]
+mod test_props;
+
 pub use one_to_one::OneToOne;
 pub use one_to_set::OneToSet;
 pub use set_to_one::SetToOne;
