@@ -77,7 +77,7 @@ impl<'a, A: Id, B: Id> ViewMultiMapLike<'a, A, B> for MFwd<'a, A, B> {
     fn contains_key(&self, a: A) -> bool { self.0.fwd.contains_key(a) }
 
     fn len(&self) -> usize { self.0.fwd.len() }
-    fn sets_len(&self) -> usize { self.0.fwd.sets_len() }
+    fn keys_len(&self) -> usize { self.0.fwd.keys_len() }
 
     fn iter(&'a self) -> Self::Iter { self.0.fwd.iter() }
     fn keys(&'a self) -> Self::Keys { self.0.fwd.keys() }
@@ -96,7 +96,7 @@ impl<'a, A: Id, B: Id> ViewMultiMapLike<'a, A, B> for VFwd<'a, A, B> {
     fn contains_key(&self, a: A) -> bool { self.0.fwd.contains_key(a) }
 
     fn len(&self) -> usize { self.0.fwd.len() }
-    fn sets_len(&self) -> usize { self.0.fwd.sets_len() }
+    fn keys_len(&self) -> usize { self.0.fwd.keys_len() }
 
     fn iter(&'a self) -> Self::Iter { self.0.fwd.iter() }
     fn keys(&'a self) -> Self::Keys { self.0.fwd.keys() }
