@@ -77,7 +77,7 @@ impl<'a, A: Id, B: Id> ViewMultiMapLike<'a, A, B> for MFwd<'a, A, B> {
     fn get(&self, a: A) -> VFwdSet<'_, A, B> { VFwdSet(self.0.fwd.get(a)) }
     fn contains_key(&self, a: A) -> bool { self.0.fwd.contains_key(a) }
     fn len(&self) -> usize { self.0.fwd.len() }
-    fn sets_len(&self) -> usize { self.0.fwd.sets_len() }
+    fn keys_len(&self) -> usize { self.0.fwd.keys_len() }
 
     fn iter(&'a self) -> Self::Iter { self.0.fwd.iter() }
     fn keys(&'a self) -> Self::Keys { self.0.fwd.keys() }
@@ -95,7 +95,7 @@ impl<'a, A: Id, B: Id> ViewMultiMapLike<'a, A, B> for VFwd<'a, A, B> {
     fn get(&self, a: A) -> VFwdSet<'_, A, B> { VFwdSet(self.0.fwd.get(a)) }
     fn contains_key(&self, a: A) -> bool { self.0.fwd.contains_key(a) }
     fn len(&self) -> usize { self.0.fwd.len() }
-    fn sets_len(&self) -> usize { self.0.fwd.sets_len() }
+    fn keys_len(&self) -> usize { self.0.fwd.keys_len() }
 
     fn iter(&'a self) -> Self::Iter { self.0.fwd.iter() }
     fn keys(&'a self) -> Self::Keys { self.0.fwd.keys() }
@@ -173,7 +173,7 @@ impl<'a, A: Id, B: Id> ViewMultiMapLike<'a, B, A> for MBwd<'a, A, B> {
     fn get(&self, b: B) -> VBwdSet<'_, A, B> { VBwdSet(self.0.bwd.get(b)) }
     fn contains_key(&self, b: B) -> bool { self.0.bwd.contains_key(b) }
     fn len(&self) -> usize { self.0.bwd.len() }
-    fn sets_len(&self) -> usize { self.0.bwd.sets_len() }
+    fn keys_len(&self) -> usize { self.0.bwd.keys_len() }
 
     fn iter(&'a self) -> Self::Iter { self.0.bwd.iter() }
     fn keys(&'a self) -> Self::Keys { self.0.bwd.keys() }
@@ -191,7 +191,7 @@ impl<'a, A: Id, B: Id> ViewMultiMapLike<'a, B, A> for VBwd<'a, A, B> {
     fn get(&self, b: B) -> VBwdSet<'_, A, B> { VBwdSet(self.0.bwd.get(b)) }
     fn contains_key(&self, b: B) -> bool { self.0.bwd.contains_key(b) }
     fn len(&self) -> usize { self.0.bwd.len() }
-    fn sets_len(&self) -> usize { self.0.bwd.sets_len() }
+    fn keys_len(&self) -> usize { self.0.bwd.keys_len() }
 
     fn iter(&'a self) -> Self::Iter { self.0.bwd.iter() }
     fn keys(&'a self) -> Self::Keys { self.0.bwd.keys() }
